==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/classPlDevice.js <==
var classPlDevice =
[
    [ "~PlDevice", "classPlDevice.html#a71fc777733f4cb842bbc42d8b5769863", null ],
    [ "BeginPage", "classPlDevice.html#a08516c6db27c87020d3b0fccd13231e7", null ],
    [ "ClearBackground", "classPlDevice.html#a691496af2bdad6325865ebf55a65ec8a", null ],
    [ "DrawLine", "classPlDevice.html#ab29aac94411dbe68c80f05f367cd580a", null ],
    [ "DrawPolyline", "classPlDevice.html#ae7cafe228d6d67085815bc074634252a", null ],
    [ "drawText", "classPlDevice.html#a3c68a9d54fcb56e68613653f5593988b", null ],
    [ "DrawTextLine", "classPlDevice.html#a252cf7172f293c7761703769b5f2ab6e", null ],
    [ "DrawTextSection", "classPlDevice.html#abca74884d734a919c2fa8c8c54ec28ca", null ],
    [ "EndPage", "classPlDevice.html#a2f63f665765273e7027ade59cb0c7cf8", null ],
    [ "FillPolygon", "classPlDevice.html#af780ccf7a6f5c60926db4c6b059ffdd7", null ],
    [ "FixAspectRatio", "classPlDevice.html#a138a8fda99a5afecb498c80f45860ee3", null ],
    [ "Flush", "classPlDevice.html#a717e4dbd351ada54b2a41361f483f2a8", null ],
    [ "Locate", "classPlDevice.html#a5683079157ddb8973f76579c41809862", null ],
    [ "PreDestructorTidy", "classPlDevice.html#aedd5435964b7c3bfd8e245fd98550f1c", null ],
    [ "SetColor", "classPlDevice.html#a1858c46f3ce1e12350f26b730052ae60", null ],
    [ "SetDC", "classPlDevice.html#a6cfe6e01c8542f9da524d9cc76569ebc", null ],
    [ "SetSize", "classPlDevice.html#a29e94cd3a22ae0353a1af3412e95245a", null ],
    [ "SetWidth", "classPlDevice.html#ade8432674c3045a20a50b5566a898bb6", null ],
    [ "m_prevBaseFontSize", "classPlDevice.html#a0b267ae488f40583873569a89e93d52e", null ],
    [ "m_prevFci", "classPlDevice.html#a6f19415b240eb3cea734ac0872a812db", null ],
    [ "m_prevSuperscriptLevel", "classPlDevice.html#a25c373593300df683def96b8a6d8f8da", null ],
    [ "m_prevSymbol", "classPlDevice.html#a0d2c637ad0172db91550e0cedd186da7", null ],
    [ "m_prevSymbolHeight", "classPlDevice.html#a6b53b14849e41acc9d14fd64326913d9", null ],
    [ "m_prevSymbolWidth", "classPlDevice.html#ae23d9a79a0d29fdcfb6cc3e4006203ed", null ]
];

==> plplot-5.13.0.tar.gz: plplot-5.13.0/doc/doxygen/html/classPlDevice.js <==
var classPlDevice =
[
    [ "PlDevice", "classPlDevice.html#a3f5badbd2cecbc88bf1b2fada540f05a", null ],
    [ "~PlDevice", "classPlDevice.html#a71fc777733f4cb842bbc42d8b5769863", null ],
    [ "BeginPage", "classPlDevice.html#a08516c6db27c87020d3b0fccd13231e7", null ],
    [ "ClearBackground", "classPlDevice.html#a691496af2bdad6325865ebf55a65ec8a", null ],
    [ "DrawLine", "classPlDevice.html#ab29aac94411dbe68c80f05f367cd580a", null ],
    [ "DrawPolyline", "classPlDevice.html#ae7cafe228d6d67085815bc074634252a", null ],
    [ "drawText", "classPlDevice.html#a3c68a9d54fcb56e68613653f5593988b", null ],
    [ "DrawTextLine", "classPlDevice.html#a4c99f2188467bd5a80948cb67311fee4", null ],
    [ "DrawTextSection", "classPlDevice.html#a07dea92732956d650c2edb2765e72b3b", null ],
    [ "EndPage", "classPlDevice.html#a2f63f665765273e7027ade59cb0c7cf8", null ],
    [ "FillPolygon", "classPlDevice.html#af780ccf7a6f5c60926db4c6b059ffdd7", null ],
    [ "FixAspectRatio", "classPlDevice.html#a138a8fda99a5afecb498c80f45860ee3", null ],
    [ "Flush", "classPlDevice.html#a717e4dbd351ada54b2a41361f483f2a8", null ],
    [ "Locate", "classPlDevice.html#a5683079157ddb8973f76579c41809862", null ],
    [ "PreDestructorTidy", "classPlDevice.html#aedd5435964b7c3bfd8e245fd98550f1c", null ],
    [ "SetColor", "classPlDevice.html#a1858c46f3ce1e12350f26b730052ae60", null ],
    [ "SetDC", "classPlDevice.html#a6cfe6e01c8542f9da524d9cc76569ebc", null ],
    [ "SetSize", "classPlDevice.html#a29e94cd3a22ae0353a1af3412e95245a", null ],
    [ "SetWidth", "classPlDevice.html#ade8432674c3045a20a50b5566a898bb6", null ],
    [ "m_prevBaseFontSize", "classPlDevice.html#a0b267ae488f40583873569a89e93d52e", null ],
    [ "m_prevFci", "classPlDevice.html#a6f19415b240eb3cea734ac0872a812db", null ],
    [ "m_prevLevel", "classPlDevice.html#ab7cf888f913ded8fbf11cf91174dffac", null ],
    [ "m_prevSymbol", "classPlDevice.html#a0d2c637ad0172db91550e0cedd186da7", null ],
    [ "m_prevSymbolDepth", "classPlDevice.html#a48c0b2f17fca05d1044d2a05ffa08191", null ],
    [ "m_prevSymbolHeight", "classPlDevice.html#a6b53b14849e41acc9d14fd64326913d9", null ],
    [ "m_prevSymbolWidth", "classPlDevice.html#ae23d9a79a0d29fdcfb6cc3e4006203ed", null ]
];
